@@ -5,28 +5,28 @@ function(params, x, batch) {
     "standardize", "ratioa", "ratiog", "noba")))
     stop("Invalid class of 'params'.")
   
-  if(class(params)=="fabatch") {
+  if(inherits(params, "fabatch")) {
     return(fabatchaddon(params, x, batch))
   }
-  if(class(params)=="combat") {
+  if(inherits(params, "combat")) {
     return(combatbaaddon(params, x, batch))
   }
-  if(class(params)=="svatrain") {
+  if(inherits(params, "svatrain")) {
     return(svabaaddon(params, x))
   }
-  if(class(params)=="meancenter") {
+  if(inherits(params, "meancenter")) {
     return(meancenteraddon(params, x, batch))
   }
-  if(class(params)=="standardize") {
+  if(inherits(params, "standardize")) {
     return(standardizeaddon(params, x, batch))
   }
-  if(class(params)=="ratioa") {
+  if(inherits(params, "ratioa")) {
     return(ratioaaddon(params, x, batch))
   }
-  if(class(params)=="ratiog") {
+  if(inherits(params, "ratiog")) {
     return(ratiogaddon(params, x, batch))
   }
-  if(class(params)=="noba") {
+  if(inherits(params, "noba")) {
     return(nobaaddon(params, x, batch))
   }
 
