@@ -3,8 +3,8 @@ function(x, batch) {
 
   if(any(is.na(x)))
 	stop("Data contains missing values.")
-  if(!(is.factor(batch) & all(levels(batch)==(1:length(levels(batch))))))
-    stop("'batch' has to be of class 'factor' with levels '1','2',...")  
+  if(!is.factor(batch))
+    stop("'batch' has to be of class 'factor'.")
   if(!is.matrix(x))
     stop("'x' has to be of class 'matrix'.") 
 
